@@ -1,5 +1,4 @@
-
-VERSION="0.1.6"
+VERSION = "0.1.8"
 HEADER = r"""'||'''|,  '||'''|, |''||''|                                  
  ||   ||   ||   ||    ||                                     
  ||;;;;    ||...|'    ||    '||),,(|,   '''|.  .|''|, .|''|, 
@@ -7,4 +6,6 @@ HEADER = r"""'||'''|,  '||'''|, |''||''|
 .||...|'  .||  \\. |..||..| .||    ||. `|..||. `|..|| `|...  
                                                    || v{}     
                                                 `..|'
-""".format(VERSION)
+""".format(
+    VERSION
+)
